@@ -14,6 +14,8 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import print_function
+from __future__ import absolute_import
 import sys
 import os
 import argparse
@@ -22,11 +24,12 @@ from calculate.lib.utils.common import getpass
 from calculate.lib.cl_print import color_print
 from calculate.lib.cl_lang import setLocalTranslate
 from calculate.core.server.api_types import TableAdapter
+from functools import reduce
 
 _ = lambda x: x
 setLocalTranslate('cl_core3', sys.modules[__name__])
 from itertools import *
-from api_types import ViewInfoAdapter, ArrayReturnedMessage, FieldAdapter
+from .api_types import ViewInfoAdapter, ArrayReturnedMessage, FieldAdapter
 from calculate.lib.utils.colortext import get_terminal_print, TextState
 
 colorPrint = color_print()
@@ -81,7 +84,7 @@ class BoolAutoAction(BoolAction):
     available_values = ("on", "off", "yes", "no", "auto")
 
 def _print(*args):
-    print " ".join(map(lambda x: _u8(x), args))
+    print(" ".join(map(lambda x: _u8(x), args)))
 
 
 def get_password(text1=None, text2=None, getfromstdin=False,
@@ -110,7 +113,7 @@ def get_password(text1=None, text2=None, getfromstdin=False,
                 return pass1
             pass2 = getpass.getpass(text2)
             if pass1 != pass2:
-                print _('Passwords do not match')
+                print(_('Passwords do not match'))
     except KeyboardInterrupt:
         return None
     passwd = pass1 if (pass1 and pass1 == pass2) else ''
