@@ -14,6 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from __future__ import absolute_import
 import sys
 
 from calculate.lib.datavars import VariableError, DataVarsError
@@ -24,12 +25,12 @@ _ = lambda x: x
 setLocalTranslate('cl_core3', sys.modules[__name__])
 __ = getLazyLocalTranslate(_)
 
-import setup_package
-import server.certificate as certificate
-import server.groups as groups
-import server.request as request
-import set_vars
-from backup import Backup, BackupError
+from . import setup_package
+from . import server.certificate as certificate
+from . import server.groups as groups
+from . import server.request as request
+from . import set_vars
+from .backup import Backup, BackupError
 from calculate.core.utils.cl_backup import ClBackupAction
 from calculate.core.utils.cl_backup_restore import ClBackupRestoreAction
 from calculate.core.server.func import WsdlBase
